@@ -1,4 +1,4 @@
-/* Copyright (c) 2003, 2004 Roger Seguin <roger_seguin@msn.com>
+/* Copyright (c) 2003-2004 Roger Seguin <roger_seguin@msn.com>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -22,7 +22,6 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-
 #include "config_gui.h"
 
 #ifdef HAVE_CONFIG_H
@@ -30,20 +29,17 @@
 #endif
 
 #include <gtk/gtk.h>
-
-#include <libxfce4util/libxfce4util.h>
 #include <libxfce4ui/libxfce4ui.h>
+#include <libxfce4util/libxfce4util.h>
 
 
-#define COPYVAL(var, field)	((var)->field = field)
+#define COPYVAL(var, field) ((var)->field = field)
 
 
-	/**** GUI initially created using glade-2 ****/
+/**** GUI initially created using glade-2 ****/
 
-	/* Use the gtk_button_new_with_mnemonic() function for text-based
-	   push buttons */
-	/* Use "#define gtk_button_new_with_mnemonic(x) gtk_button_new()"
-	   for color-filled buttons */
+/* Use the gtk_button_new_with_mnemonic() function for text-based push buttons */
+/* Use "#define gtk_button_new_with_mnemonic(x) gtk_button_new()" for color-filled buttons */
 
 #define gtk_button_new_with_mnemonic(x) gtk_button_new()
 
@@ -66,7 +62,6 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     GtkWidget      *wTB_Title;
     GtkWidget      *wTF_Title;
     GtkWidget      *hseparator7;
-    GtkWidget      *hbox2;
     GtkWidget      *label9;
     GtkWidget      *wRB_IO;
     GSList         *wRB_IO_group = NULL;
@@ -83,7 +78,6 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     GtkWidget      *label5;
     GtkWidget      *label6;
     GtkWidget      *label8;
-    GtkWidget      *hbox1;
     GtkWidget      *wRB_ReadWriteOrder;
     GSList         *wRB_ReadWriteOrder_group = NULL;
     GtkWidget      *wRB_WriteReadOrder;
@@ -112,8 +106,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_show (wTF_Device);
     gtk_widget_set_hexpand (wTF_Device, TRUE);
     gtk_grid_attach (GTK_GRID (table1), wTF_Device, 1, 0, 2, 1);
-    gtk_widget_set_tooltip_text (wTF_Device,
-			  _("Input the device name, then press <Enter>"));
+    gtk_widget_set_tooltip_text (wTF_Device, _("Input the device name, then press <Enter>"));
     gtk_entry_set_max_length (GTK_ENTRY (wTF_Device), 128);
     gtk_entry_set_text (GTK_ENTRY (wTF_Device), _("/dev/sda1"));
 
@@ -124,8 +117,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_set_hexpand(GTK_WIDGET(eventbox1), TRUE);
 
     wSc_Period_adj = gtk_adjustment_new (0.5, 0.25, 4, 0.05, 1, 0);
-    wSc_Period =
-	gtk_spin_button_new (GTK_ADJUSTMENT (wSc_Period_adj), 1, 3);
+    wSc_Period = gtk_spin_button_new (GTK_ADJUSTMENT (wSc_Period_adj), 1, 3);
     gtk_widget_set_halign (GTK_WIDGET (wSc_Period), GTK_ALIGN_START);
     gtk_widget_show (wSc_Period);
     gtk_container_add (GTK_CONTAINER (eventbox1), wSc_Period);
@@ -146,8 +138,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     wTF_Title = gtk_entry_new ();
     gtk_widget_show (wTF_Title);
     gtk_grid_attach (GTK_GRID (table1), wTF_Title, 1, 1, 2, 1);
-    gtk_widget_set_tooltip_text (wTF_Title,
-			  _("Input the label, then press <Enter>"));
+    gtk_widget_set_tooltip_text (wTF_Title, _("Input the label, then press <Enter>"));
     gtk_entry_set_max_length (GTK_ENTRY (wTF_Title), 16);
     gtk_entry_set_text (GTK_ENTRY (wTF_Title), _("hda1"));
 
@@ -170,16 +161,12 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_radio_button_set_group (GTK_RADIO_BUTTON (wRB_IO), wRB_IO_group);
     wRB_IO_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_IO));
 
-    wRB_BusyTime =
-	gtk_radio_button_new_with_mnemonic (NULL, _("Busy time"));
+    wRB_BusyTime = gtk_radio_button_new_with_mnemonic (NULL, _("Busy time"));
     gtk_widget_show (wRB_BusyTime);
     gtk_grid_attach (GTK_GRID (table1), wRB_BusyTime, 2, 4, 1, 1);
-    gtk_widget_set_tooltip_text (wRB_BusyTime,
-			  _("Percentage of time the device is busy"));
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (wRB_BusyTime),
-				wRB_IO_group);
-    wRB_IO_group =
-	gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_BusyTime));
+    gtk_widget_set_tooltip_text (wRB_BusyTime, _("Percentage of time the device is busy"));
+    gtk_radio_button_set_group (GTK_RADIO_BUTTON (wRB_BusyTime), wRB_IO_group);
+    wRB_IO_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_BusyTime));
 
     wHBox_MaxIO = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_widget_show (wHBox_MaxIO);
@@ -199,7 +186,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_set_hexpand (wTF_MaxXfer, TRUE);
     gtk_box_pack_start (GTK_BOX (wHBox_MaxIO), wTF_MaxXfer, FALSE, TRUE, 0);
     gtk_widget_set_tooltip_text (wTF_MaxXfer,
-			  _("Input the maximum I/O transfer rate of the device, then press <Enter>"));
+                                 _("Input the maximum I/O transfer rate of the device, then press <Enter>"));
     gtk_entry_set_max_length (GTK_ENTRY (wTF_MaxXfer), 5);
     gtk_entry_set_text (GTK_ENTRY (wTF_MaxXfer), _("35"));
 
@@ -209,12 +196,10 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_show (hseparator8);
     gtk_grid_attach (GTK_GRID (table1), hseparator8, 0, 6, 3, 1);
 
-    wTB_RWcombined =
-	gtk_check_button_new_with_mnemonic (_("Combine Read/Write data"));
+    wTB_RWcombined = gtk_check_button_new_with_mnemonic (_("Combine Read/Write data"));
     gtk_widget_show (wTB_RWcombined);
     gtk_grid_attach (GTK_GRID (table1), wTB_RWcombined, 0, 7, 3, 1);
-    gtk_widget_set_tooltip_text (wTB_RWcombined,
-			  _("Combine Read/Write data into one single monitor?"));
+    gtk_widget_set_tooltip_text (wTB_RWcombined, _("Combine Read/Write data into one single monitor?"));
 
     wTa_SingleBar = gtk_grid_new ();
     gtk_grid_set_column_spacing(GTK_GRID (wTa_SingleBar), 12);
@@ -266,27 +251,19 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_set_valign (GTK_WIDGET (label8), GTK_ALIGN_CENTER);
     gtk_label_set_xalign (GTK_LABEL (label8), 0.0f);
 
-    wRB_ReadWriteOrder =
-	gtk_radio_button_new_with_mnemonic (NULL, _("Read-Write"));
+    wRB_ReadWriteOrder = gtk_radio_button_new_with_mnemonic (NULL, _("Read-Write"));
     gtk_widget_show (wRB_ReadWriteOrder);
     gtk_grid_attach (GTK_GRID (wTa_DualBars), wRB_ReadWriteOrder, 1, 0, 1, 1);
-    gtk_widget_set_tooltip_text (wRB_ReadWriteOrder,
-			  _("\"Read\" monitor first"));
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (wRB_ReadWriteOrder),
-				wRB_ReadWriteOrder_group);
-    wRB_ReadWriteOrder_group =
-	gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_ReadWriteOrder));
+    gtk_widget_set_tooltip_text (wRB_ReadWriteOrder, _("\"Read\" monitor first"));
+    gtk_radio_button_set_group (GTK_RADIO_BUTTON (wRB_ReadWriteOrder), wRB_ReadWriteOrder_group);
+    wRB_ReadWriteOrder_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_ReadWriteOrder));
 
-    wRB_WriteReadOrder =
-	gtk_radio_button_new_with_mnemonic (NULL, _("Write-Read"));
+    wRB_WriteReadOrder = gtk_radio_button_new_with_mnemonic (NULL, _("Write-Read"));
     gtk_widget_show (wRB_WriteReadOrder);
     gtk_grid_attach (GTK_GRID (wTa_DualBars), wRB_WriteReadOrder, 2, 0, 1, 1);
-    gtk_widget_set_tooltip_text (wRB_WriteReadOrder,
-			  _("\"Write\" monitor first"));
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (wRB_WriteReadOrder),
-				wRB_ReadWriteOrder_group);
-    wRB_ReadWriteOrder_group =
-	gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_WriteReadOrder));
+    gtk_widget_set_tooltip_text (wRB_WriteReadOrder, _("\"Write\" monitor first"));
+    gtk_radio_button_set_group (GTK_RADIO_BUTTON (wRB_WriteReadOrder), wRB_ReadWriteOrder_group);
+    wRB_ReadWriteOrder_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_WriteReadOrder));
 
     wPB_Rcolor = gtk_color_button_new();
     gtk_widget_show (wPB_Rcolor);
@@ -301,22 +278,22 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_set_hexpand (GTK_WIDGET (wPB_Wcolor), TRUE);
 
     if (p_poGUI) {
-	COPYVAL (p_poGUI, wTF_Device);
-	COPYVAL (p_poGUI, wSc_Period);
-	COPYVAL (p_poGUI, wTB_Title);
-	COPYVAL (p_poGUI, wTF_Title);
-	COPYVAL (p_poGUI, wRB_IO);
-	COPYVAL (p_poGUI, wRB_BusyTime);
-	COPYVAL (p_poGUI, wHBox_MaxIO);
-	COPYVAL (p_poGUI, wTF_MaxXfer);
-	COPYVAL (p_poGUI, wTB_RWcombined);
-	COPYVAL (p_poGUI, wTa_SingleBar);
-	COPYVAL (p_poGUI, wTa_DualBars);
-	COPYVAL (p_poGUI, wRB_ReadWriteOrder);
-	COPYVAL (p_poGUI, wRB_WriteReadOrder);
-	COPYVAL (p_poGUI, wPB_RWcolor);
-	COPYVAL (p_poGUI, wPB_Rcolor);
-	COPYVAL (p_poGUI, wPB_Wcolor);
+        COPYVAL (p_poGUI, wTF_Device);
+        COPYVAL (p_poGUI, wSc_Period);
+        COPYVAL (p_poGUI, wTB_Title);
+        COPYVAL (p_poGUI, wTF_Title);
+        COPYVAL (p_poGUI, wRB_IO);
+        COPYVAL (p_poGUI, wRB_BusyTime);
+        COPYVAL (p_poGUI, wHBox_MaxIO);
+        COPYVAL (p_poGUI, wTF_MaxXfer);
+        COPYVAL (p_poGUI, wTB_RWcombined);
+        COPYVAL (p_poGUI, wTa_SingleBar);
+        COPYVAL (p_poGUI, wTa_DualBars);
+        COPYVAL (p_poGUI, wRB_ReadWriteOrder);
+        COPYVAL (p_poGUI, wRB_WriteReadOrder);
+        COPYVAL (p_poGUI, wPB_RWcolor);
+        COPYVAL (p_poGUI, wPB_Rcolor);
+        COPYVAL (p_poGUI, wPB_Wcolor);
     }
-    return (0);
-}				/* CreateConfigGUI() */
+    return 0;
+}
